# Open Material Archiving

![](../images/presentation-4.jpg)*Material samples, Loes Bogers, 2020*

##Goals of the project

The goal of this project was to explore and develop simple methods for open material archiving that is....

- not only ecologically, but also historically, culturally, geographically aware
- extending material activism beyond bioplastics
- promoting open-source attitude to the development of design materials
- getting down and dirty: from buying your ingredients, all the way to tips and tricks for that challenging phase of controlled drying and curing materials to its "final" form.
- explained in layman's terms, demystifying without oversimplifying ingredients or processes
- explicitly facilitating critique, contestations, suggestions, updates and reviews from peers (once the digital database is fully realized)
- offering a package that allows novices to learn, and educators to get started in a systematic way.

##Deliverables

- [**development brief**](https://docs.google.com/presentation/d/1YRHikbOnj0WLbVhc2BELcTUBk30rFFGOpYzF1ra7Jp4/edit?usp=sharing) for a context-aware, collaborative materials database
- [**25 foundational recipes**](../recipes) to start your own sample archive (based on ingredients that are largely locally abundant in the Netherlands)
- [**list of tools**](../tools) needed to start your own material samples archive
- [**video tutorial**](https://www.youtube.com/playlist?list=PLXJnjBsCdBxGIRjgl9SVeoAYn7UzqS8A6) for capturing tactility of material samples
- [**template for new recipes**](./templates/new_recipe), to help you capture the entire proces, ask the hard contextual questions and document relevant considerations when contributing new recipes to the database.
- [**template to add new ingredients**](./templates/new_ingredient), helping you ask the hard questions and document relevant considerations when contributing new recipes to the database.
- [**templates for labels**](./templates/labels) to create your own physical archive with material samples (building on the work of Maria Viftrup for TextileLab Waag).
- [**a glossary of terms**](./glossary), explaining the key terms used here (in progress)
- [**an educators' note**](./z_educators_note) with some suggestions for how this archive might be incorporated into classes oriented to designing/material research/critical making/design & crafts history/machine building classes.

###Future development

- realising the online database further with a designer and developer
- develop, document and add methods for simple material testing
- add section for open-source DIY tools for fabrication
- testing these formats as tools for learning in higher education and fabricademy, gathering peer feedback from peers

##Overview

1. (WHAT) The project: title and phrase that describes it (vision/mission)
2. (WHAT) A poster (like a pager, advertisement or design overview)
3. (WHY) Inspiration and State of the art: timeline of projects/research
that is relevant to your state of art
4. (WHY/WHO) Numbers/statistics (optional - if you have conducted an inquiry)
5. (WHY/WHO) References: Case studies and existing similar projects (4 max)
6. (for WHO) Case study - user experience, make an assumption of a
person (character) that uses it (if applicable)
7. (HOW) How does your prototype/project manifest your idea, what it
tackles, improves or changes from the state of the art
8. (HOW) Technical research: Outline of how it materializes the goal/focus of the project
9. (HOW/DOCUMENTATION) User manual if it is a machine or kit
10. Message to the world: what is the project's message? in one line define the future possibilities of the project.

##1. AN ARCHIVE OF DIY, OPEN-SOURCE MATERIALS

A curated selection from best practices found in research labs, material archives and design studios from all over the world. The information itself was already widely known, this project is an effort to ask new questions, and think up new structures for organising and building on this knowledge in open, collaborative ways, not over-simplifying nor mystifying the information and skills needed. 

What is offered here: 

- A starter pack with a **selection of 25 DIY recipes for biobased alternatives to common design materials** like inks, dyes, (thermoformed and thermoset) plastics, composites, leathers and crystals. 
- **An invitation to develop your own selection of 25 core recipes**, to suit *your* local context and ingredients locally abundant around you. The materials are selected based on the local availability of their ingredients in the Netherlands (e.g. potato starch produced locally, instead of corn starch, dye of onion skins instead of hibiscus tea). 
- **Description of the cultural origins** of each material and the techniques involved (which may be questioned and expanded)
- **Ethical and ecological considerations** for each material (which can be questioned and expanded)
- **A set of tools for local archiving** to enable sensory exploration of the open-source materials available and aid material-driven design pedagogy.
- **A framework for collaborative online archiving** following these principles, that can be further developed in the future


##2. BECAUSE MATERIAL ACTIVISM NEEDS DEMYSTIFICATION

- **we need *ongoing* material activism**, especially in the face of smart and advanced materials increasing popularity. What could be methods to continue to demystify material craftsmanship as materials research evolves and becomes highly technical and less accessible due to increasing complexity as well as patenting intellectual property?
- **if plactics are not the only issue, then bioplastics are not the only solution**, dyeing and chemical treatments and finishes are equally if hazardous for the environment and workers.
- **designers and makers need to get comfortable drawing from different fields of knowledge** and their methods like empirical approaches and systematic ways of experimenting and documenting, such as in fields of biology, chemistry and other "hard" sciences.
- but we need to be equally **aware of history, cultural heritage and the politics of design materials** in terms of their cultural history, as well as their socio-economic and ecological implications. 
- **we need open-source material knowledge**: if resources are part of the commons, then so are material kowledge and craftsmanship, but we need to contiue to build it up and keep it alive. 


##3. FOR THE OBSESSIVELY CURIOUS, THE CRITICAL MAKERS, THE MATERIAL LOVERS 

*You are a maker or designer, a design student or maker educator. Your are o board with all of this. Where and how do I start, you ask?*

- **make materials from scratch**: as this will bring the entire ecology of material knowledge, production, distribution and legislation into view and open to questioning;
- **cultivate material craftsmanship** and understand the importance time and controlled environments effect on a material's growth/curing/drying. But equally, learn to work *with* any material (rather than expecting it to bend to your will). 
- look for and learn to appreciate **locally abundant resources** and their potential, and start to see them appear in very unlikely places;
- **spend time with materials and resources**, attention and dedication to the cooking/curing/drying or growth process will allow you to start seeing alternative uses, options, applications.
- **learn from practices from all over the world** to strengthen your own locally centered practice (not yielding to the temptation of turning that wealth of knowledge into a candy shop);
- **ask questions to stay with the trouble** of socalled sustainable materials, rather than setting out to find silver bullet solutions.
- **document and share** your process, research and outcomes using formats to describe their sensory and technical properties, and give an impression of their tactile, and auditory qualities. 

-------
-------
----------

BLURB BLURB BLURBS BELOW

---------
---------
-------------


##What?

A proposal for an online accessible *open-source material archive with DIY recipes for renewable and biocompostable (or recycled) materials for designers*. It is based on the knowledge collected and created in and around the Fabricademy network, and builds upon the (physical) Material Archive at Textile Lab Waag that was realised by Cecilia Raspanti, Maria Viftrup and others in 2016-2017.

A selection of 25 biofabricated materials is already documented and forms a suggested "starter archive" for anyone who would like to build their own physical archive with samples. Building the basic archive will teach you the foundational techniques that most other recipes will build upon, and require you to collect the basic tools and ingredients you will need.

I analysed at a number of online and offline archives, such as Materiom (link), Materiability (link), The Institute of Making at UCL London), 
Material Archive Textile Lab Amsterdam (link), Material District (link) for how they....
- item 1
- item 2
- item 3


##Why?

**Biofabricating can be further demystified**

Some archives tend to mystify the process of biofabricating (using expert terminology, not explaining in detail how to actually do something). Getting very scientific or very technical about it without explaining hands-on knowledge in laymen's terms.

**Biofabrication can be further clarifying (but not simplified!)**

alternatively, archives and resources tend to oversimplify the process (a three step summary of a process where many more intricated details matter. Knowing how to cook a bioplastic is easy, knowing how to dry it well is much less documented.

**Material Archives can and should take an open-source DIY approach (Do-It-Yourself)**

Many archives will show you what's out there (to buy), but don't give the concrete info you need to biofabricate yourself even though you can often try out these things in your kitchen and most recipes are in the commons and can be used by anyone.

**Do-It-Together**

When recipes and how-to's are shared (e.g. Material Archive, Materiability etc.) there is often no way to disagree on recipes. What is there is there and cannot be improved or responded to by others. 

**Context-aware approach (exit the candy shop)**

A lot of 

**Tactile / sound demo often lacking but very necessary**

The tactile dimension that is so important part of a physical archive is lacking in most online ones to help people understand the kind of material they can make with a given recipe

Other arguments:

- sustainability
- nuance: no perfect material but let's collect information
- not mystifying
- but also not simplifying
- technique is half the work
- thorough documentation and referencing highlighted
- thorough and feedback system by committed peers
- local specificity
- cultural/historical perspective incl contestations
- including technical and sensory specifics
- tactile / sound demo often lacking but very necessary


##Who?

Designers, material crafters, students, educators, researchers, hobbyists.

The recipes in the archive are accessible to anyone with a device that has a browser and an internet connection. 


Anyone dedicated to biofabricating materials and some experience in at least one of the processes can submit a recipe manually. If the recipe is thoroughly researched, the person can join as a contributor and get a log-in account. 


##References


##Process


##Future steps




-------------


## Research

- sensory description system
- technical qualities
- raw vs. made
- physical form
- organic vs. inorganic
- criteria

## Definitions

- Abundance-aware (local physical archive only from locally abundant materials)
- Circular
- Plant-based/vegan if possible
- Cruelty free
- Non-toxic
- Contested
- Biobased, biodegradable, biocompostable
- Open-source (we know how it's made)

## Decisions

- color comes from somewhere too: no added colors
- until we know how synthetic food coloring is made, no food coloring
- color is a material
- stuff that is grown in a controlled environment is also "made"
- physical selection should show variation in *physical forms*, and show the main ingredient types we know to use to biofabricate.
- physical selection is made in such a way to also demonstrate a variety in textures and sensory qualities
- recipes should include pointers for drying/curing
- recycling or upcycling also has a place in the archive
- we don't use food unless it's considered waste (e.g. onion skins, egg shells, overripe mangos from the market). So no fresh berries for dye.

## Local archive

- Every new  entry is a variation on an existing one
- A variation can only entail _one change_ at a time (don't change both the additive and the curing process).
- Reason for the variation is stated (e.g. local tap water is too alkaline so we use mineral water, wanted a more flexible biosilicon).
- Shows relationships between the samples (network)?

### Local recipe should include

- ingredients 
- utensils
- process
- drying tips/tricks
- pros and cons/concerns/contestations/question marks
- potential health hazards
- estimated cost and vendors
- technical qualities (e.g. water/heat/light proof?)

## Digital archive

- Includes all information except hyperlocal info
- A new entry is made when the recipe is changed to the extent that the qualities of the material change and the sensory descriptions do not match the resulting material anymore.
- The criterium of being locally abundant does not apply here.
- Entries should state where an ingredient is grown/sourced.
- Entries should state how long it takes for an ingredient to renew itself. 
- Entries should state the cultural and/or intellectual history of the material (including references or further reading)
- Entries should describe the sensory qualities of any material (because this is lost in digitization)
- Entries contain a video/gif for sound and haptic info

### Keep options open for

- info about technical material tests
- chemical interactions etc
- techniques, case studies, applications
- peer reviewing/upvoting
- section for techniques
- section for open-source tooling


